rm(list = ls())
library(limma)
library(ggpubr)
tideFile="TIDE.txt"    
riskFile="risk.all.txt"     
rt=read.table(tideFile, header=T, sep="\t", check.names=F)
rt=as.matrix(rt)
rownames(rt)=rt[,1]
exp=rt[,2:ncol(rt)]
dimnames=list(rownames(exp),colnames(exp))
data=matrix(as.numeric(as.matrix(exp)),nrow=nrow(exp),dimnames=dimnames)
data = data[,3:8]
group=sapply(strsplit(row.names(data),"\\-"), "[", 4)
group=sapply(strsplit(group,""), "[", 1)
group=gsub("2", "1", group)
tide=data[group==0,,drop=F]
row.names(tide)=gsub("(.*?)\\-(.*?)\\-(.*?)\\-(.*)", "\\1\\-\\2\\-\\3", row.names(tide))
risk=read.table(riskFile, header=T, sep="\t", check.names=F, row.names=1)
sameSample=intersect(row.names(tide), row.names(risk))
tide=tide[sameSample, , drop=F]
risk=risk[sameSample, "risk", drop=F]
data=cbind(tide, risk)
data$risk=ifelse(data$risk=="low", "Low-risk", "High-risk")
group=levels(factor(data$risk))
comp=combn(group,2)
my_comparisons=list()
for(i in 1:ncol(comp)){my_comparisons[[i]]<-comp[,i]}
gg1=ggviolin(data, x="risk", y="TIDE", fill = "risk", 
             xlab="", ylab="TIDE",
             palette=c("indianred","mediumseagreen"),
             legend.title="risk",
             add = "boxplot", add.params = list(fill="khaki2"))+ 
  stat_compare_means(comparisons = my_comparisons)

pdf(file="TIDE.pdf", width=3.5, height=4)
print(gg1)
dev.off()

