rm(list = ls())
library(plyr)
library(ggplot2)
library(ggpubr)
scoreFile="risk.all.txt"    
cliFile="ImmuCellAI_icb_result.txt"       
trait="Response"            
score=read.table(scoreFile, header=T, sep="\t", check.names=F, row.names=1)
Response=read.table(cliFile, header=T, sep="\t", check.names=F, row.names=1)
sameSample=intersect(row.names(score), row.names(Response ))
rt=cbind(score[sameSample,,drop=F], Response[sameSample,,drop=F])
bioCol=c("red2","limegreen","#FF9900","#6E568C")
rt1=rt[,c(trait, "risk")]
colnames(rt1)=c("trait", "group")
df=as.data.frame(table(rt1))

df=ddply(df, .(group), transform, percent = Freq/sum(Freq) * 100)

df=ddply(df, .(group), transform, pos = (cumsum(Freq) - 0.5 * Freq))
df$label=paste0(sprintf("%.0f", df$percent), "%")
df$group=factor(df$group, levels=c("low", "high"))

p=ggplot(df, aes(x = factor(group), y = percent, fill = trait)) +
  geom_bar(position = position_stack(), stat = "identity", width = .6) +
  scale_fill_manual(values=bioCol)+
  xlab("risk score")+ ylab("Percent weight")+  guides(fill=guide_legend(title=trait))+
  geom_text(aes(label = label), position = position_stack(vjust = 0.5), size = 4.5) +
  coord_flip()+
  theme(legend.position = "top")

print(p)
pdf(file="ImmuCellAI.PercentWeight.pdf", width=4, height=3)
print(p)
dev.off()

rt2=rt[,c(trait, "riskScore")]
rt2$riskScore[rt2$riskScore>quantile(rt2$riskScore,0.99)]=quantile(rt2$riskScore,0.99)
rt2$riskScore = log2(rt2$riskScore)
colnames(rt2)=c("trait", "riskScore")
bioCol=c("limegreen","red2","#FF9900","#6E568C")
type=levels(factor(rt2[,"trait"]))
comp=combn(type, 2)
my_comparisons=list()
for(i in 1:ncol(comp)){my_comparisons[[i]]<-comp[,i]}

boxplot=ggboxplot(rt2, x="trait", y="riskScore", fill="trait",
                  xlab=trait,
                  add = "jitter",
                  #color = "trait",
                  ylab="riskScore (log2)",
                  legend.title=trait,
                  palette=bioCol
)+ 
  stat_compare_means(comparisons=my_comparisons)

print(boxplot)

pdf(file="ImmuCellAI.scatter.pdf",width=3.5,height=4.5)
print(boxplot)
dev.off()











