
#install.packages("survival")
#install.packages("survminer")


#
library(survival)
library(survminer)



bioSurvival=function(inputFile=null, outFile=null){
	#
	rt=read.table(inputFile, header=T, sep="\t")
	#
	diff=survdiff(Surv(futime, fustat) ~risk,data = rt)
	pValue=1-pchisq(diff$chisq,df=1)
	if(pValue<0.001){
	  pValue=paste0("p=",signif(pValue,4)) 
	  pValue=format(pValue, scientific = TRUE)
	}  else{
	  pValue=paste0("p=",round(pValue,3)) 
	}
	fit <- survfit(Surv(futime, fustat) ~ risk, data = rt)
		
	#
	surPlot=ggsurvplot(fit, 
		           data=rt,
		           conf.int=T,
		           pval=pValue,
		           pval.size=4.6,
		           legend.title="Risk",
		           legend.labs=c("High risk", "Low risk"),
		           xlab="Time(years)",
		           ylab="Overall survival",
		           break.time.by = 2,
		           palette=c("red1", "limegreen"),
		           risk.table=TRUE,
		       	   risk.table.title="",
		           risk.table.col = "strata",
		           risk.table.height=.28)
	
	
	pdf(file=outFile, width = 3.9, height =4.5, onefile = FALSE)
	print(surPlot)
	dev.off()
}

#
bioSurvival(inputFile="risk.train.txt", outFile="surv.train.pdf")
bioSurvival(inputFile="risk.test.txt", outFile="surv.test.pdf")
bioSurvival(inputFile="risk.all.txt", outFile="surv.all.pdf")




