#install.packages("survival")
#install.packages("survminer")
#install.packages("timeROC")

rm(list = ls())
library(survival)
library(survminer)
library(timeROC)

riskFile="risk.all.txt"    
cliFile="TCGA.KIRC-cli.txt"      

risk=read.table(riskFile, header=T, sep="\t", check.names=F, row.names=1)
risk=risk[,c("futime", "fustat", "riskScore")]

cli=read.table(cliFile, header=T, sep="\t", check.names=F, row.names=1)
cli = cli[,c(1:4,6:9)]
library(dplyr)
cli = cli %>% distinct(`_PATIENT`, .keep_all = T)
rownames(cli) = cli$`_PATIENT`
cli = cli[2:ncol(cli)]
colnames(cli)
#cli = cli[c(1,2,3,4,5,6,7,8)]
colnames(cli) = c("age","gender","grade",
                 # "laterality",
                  "stage",
                  "T",
                  "M",
                  "N")

samSample=intersect(row.names(risk), row.names(cli))
risk1=risk[samSample,,drop=F]
cli=cli[samSample,,drop=F]
rt=cbind(risk1, cli)

bioCol=rainbow(ncol(rt)-1, s=0.9, v=0.9)


ROC_rt=timeROC(T=risk$futime,delta=risk$fustat,
	           marker=risk$riskScore,cause=1,
	           weighting='aalen',
	           times=c(1,3,5,7,10),ROC=TRUE)
pdf(file="all.ROC.pdf", width=4.5, height=5)
plot(ROC_rt,time=1,col=bioCol[1],title=FALSE,lwd=2)
plot(ROC_rt,time=3,col=bioCol[2],add=TRUE,title=FALSE,lwd=2)
plot(ROC_rt,time=5,col=bioCol[3],add=TRUE,title=FALSE,lwd=2)
plot(ROC_rt,time=7,col=bioCol[4],add=TRUE,title=FALSE,lwd=2)
plot(ROC_rt,time=10,col=bioCol[5],add=TRUE,title=FALSE,lwd=2)
legend('bottomright',
	   c(paste0('AUC at 1 years: ',sprintf("%.03f",ROC_rt$AUC[1])),
	     paste0('AUC at 3 years: ',sprintf("%.03f",ROC_rt$AUC[2])),
	     paste0('AUC at 5 years: ',sprintf("%.03f",ROC_rt$AUC[3])),
	     paste0('AUC at 7 years: ',sprintf("%.03f",ROC_rt$AUC[4])),
	     paste0('AUC at 10 years: ',sprintf("%.03f",ROC_rt$AUC[5]))),
	   col=bioCol[1:5], lwd=2, bty = 'n')
dev.off()



predictTime=5     
aucText=c()
pdf(file="all.cliROC.pdf", width=5.3, height=5.6)

i=3
ROC_rt=timeROC(T=risk$futime,
               delta=risk$fustat,
               marker=risk$riskScore, cause=1,
               weighting='aalen',
               times=c(predictTime),ROC=TRUE)
plot(ROC_rt, time=predictTime, col=bioCol[i-2], title=FALSE, lwd=2.5)
aucText=c(paste0("Risk", ", AUC=", sprintf("%.3f",ROC_rt$AUC[2])))
abline(0,1)

for(i in 4:ncol(rt)){
	ROC_rt=timeROC(T=rt$futime,
				   delta=rt$fustat,
				   marker=rt[,i], cause=1,
				   weighting='aalen',
				   times=c(predictTime),ROC=TRUE)
	plot(ROC_rt, time=predictTime, col=bioCol[i-2], title=FALSE, lwd=2.5, add=TRUE)
	aucText=c(aucText, paste0(colnames(rt)[i],", AUC=",sprintf("%.3f",ROC_rt$AUC[2])))
}

legend("bottomright", aucText,lwd=2,bty="n",col=bioCol[1:(ncol(rt)-1)])
dev.off()



