library(pheatmap)       

bioRiskPlot=function(inputFile=null, riskScoreFile=null, survStatFile=null, heatmapFile=null){
	rt=read.table(inputFile, header=T, sep="\t", check.names=F, row.names=1)   
	rt=rt[order(rt$riskScore),]      
		
	
	riskClass=rt[,"risk"]
	lowLength=length(riskClass[riskClass=="low"])
	highLength=length(riskClass[riskClass=="high"])
	lowMax=max(rt$riskScore[riskClass=="low"])
	line=rt[,"riskScore"]
	line[line>10]=10
	pdf(file=riskScoreFile, width=6, height=2.8)
	plot(line, type="p", pch=20,
		 xlab="Patients (increasing risk socre)", ylab="Risk score",
		 col=c(rep("royalblue",lowLength),rep("gray66",highLength)) )
	abline(h=lowMax,v=lowLength,lty=2)
	legend("topleft", c("High risk", "Low Risk"),bty="n",pch=19,col=c("gray66","royalblue"),cex=1.2)
	dev.off()
		
	
	color=as.vector(rt$fustat)
	color[color==1]="gray66"
	color[color==0]="royalblue"
	pdf(file=survStatFile, width=6, height=2.8)
	plot(rt$futime, pch=19,
		 xlab="Patients (increasing risk socre)", ylab="Survival time (years)",
		 col=color)
	legend("topright", c("Dead", "Alive"),bty="n",pch=19,col=c("gray66","royalblue"),cex=1.2)
	abline(v=lowLength,lty=2)
	dev.off()
		
	
	rt1=rt[c(3:(ncol(rt)-2))]
	rt1=t(rt1)
	annotation=data.frame(type=rt[,ncol(rt)])
	rownames(annotation)=rownames(rt)
	pdf(file=heatmapFile, width=6, height=1.7)
	pheatmap(rt1, 
		     annotation=annotation, 
		     cluster_cols = F,
		     cluster_rows = F,
		     show_colnames = F,
		     scale="row",
		     color = colorRampPalette(c(rep("black",5), "white", rep("deeppink",5)))(50),
		     fontsize_col=3,
		     fontsize=7,
		     fontsize_row=8)
	dev.off()
}


bioRiskPlot(inputFile="risk.train.txt",
            riskScoreFile="train.riskScore.pdf",
            survStatFile="train.survStat.pdf",
            heatmapFile="train.heatmap.pdf")
bioRiskPlot(inputFile="risk.test.txt",
            riskScoreFile="test.riskScore.pdf",
            survStatFile="test.survStat.pdf",
            heatmapFile="test.heatmap.pdf")

bioRiskPlot(inputFile="risk.all.txt",
            riskScoreFile="all.riskScore.pdf",
            survStatFile="all.survStat.pdf",
            heatmapFile="all.heatmap.pdf")


