#Nomogram and calibration curve
rm(list = ls())
library(survival)
library(regplot)
library(rms)
riskFile="risk.all.riskScore12.txt"      

cliFile="cli.all.txt"       

risk=read.table(riskFile, header=T, sep="\t", check.names=F, row.names=1)

cli=read.table(cliFile, header=T, sep="\t", check.names=F, row.names=1)
cli=as.data.frame(cli)
cli=cli[,c(1,3,4)]
cli=cli[apply(cli,1,function(x)any(is.na(match('Unknown',x)))),,drop=F]
cli$age=as.numeric(cli$age)
cli[,"stage"]=ifelse(cli[,"stage"]==1, "I", ifelse(cli[,"stage"]>3,"IV",
                                                      ifelse(cli[,"stage"]>2,"III","II")))
cli[,"grade"]=ifelse(cli[,"grade"]==1, "G1-2", ifelse(cli[,"grade"]>3,"G3-4",
                                                   ifelse(cli[,"grade"]>2,"G3-4","G1-2")))
risk[,"riskScore"] = ifelse(risk[,"riskScore"]==1,"Low risk","High risk"     )

samSample=intersect(row.names(risk), row.names(cli))
risk1=risk[samSample,,drop=F]
cli=cli[samSample,,drop=F]
rt=cbind(risk1[,c("futime", "fustat", "riskScore")], cli)

res.cox=coxph(Surv(futime, fustat) ~ . , data = rt)
nom1=regplot(res.cox,
             plots = c("density", "boxes"),
             clickable=F,
             title="",
             points=TRUE,
             droplines=TRUE,
             #observation=rt[16,],
             rank="sd",
             failtime = c(1,3,5,10),
             prfail = F)

nomoRisk=predict(res.cox, data=rt, type="risk")
rt=cbind(risk1, Nomogram=nomoRisk)
outTab=rbind(ID=colnames(rt), rt)
write.table(outTab, file="nomoRisk.age12.stage12.txt", sep="\t", col.names=F, quote=F)
#############################################################


#
rm(list = ls())
cliFile="cli.all.age12.stage12.txt"       
risk=read.table("nomoRisk.age12.stage12.txt", header=T, sep="\t", check.names=F, row.names=1)
cli=read.table(cliFile, header=T, sep="\t", check.names=F, row.names=1)
cli=as.data.frame(cli)
cli=cli[,c(1,3:4)]
samSample=intersect(row.names(risk), row.names(cli))
risk1=risk[samSample,,drop=F]
cli=cli[samSample,,drop=F]
rt=cbind(risk1[,c("futime", "fustat", "riskScore","Nomogram")], cli)

library(timeROC)
library(survival)
ROC_nomo <- timeROC(T=rt$futime, #
                    delta=rt$fustat, #
                    marker=rt$Nomogram , #
                    cause=1, 
                    weighting="marginal", #
                    times=c(1,2,3,4,5,6,7,8,9,10),
                  iid=TRUE)

ROC_riskscore <- timeROC(T=rt$futime, 
                         delta=rt$fustat, 
                         marker=rt$riskScore, #
                         cause=1, #
                         weighting="marginal", # 
                         times=c(1,2,3,4,5,6,7,8,9,10), 
                         #
                         iid=TRUE)
ROC_age <- timeROC(T=rt$futime, #
                   delta=rt$fustat, #
                   marker=rt$age, # 
                   cause=1, #
                   weighting="marginal", #
                   times=c(1,2,3,4,5,6,7,8,9,10), 
                   # 
                   iid=TRUE)
ROC_stage <- timeROC(T=rt$futime, 
                     delta=rt$fustat, 
                     marker=rt$stage, 
                     cause=1,
                     weighting="marginal", 
                     times=c(1,2,3,4,5,6,7,8,9,10), 
                     iid=TRUE)
ROC_grade <- timeROC(T=rt$futime, #
                     delta=rt$fustat, 
                     marker=rt$grade, 
                     cause=1,  
                     weighting="marginal",
                     times=c(1,2,3,4,5,6,7,8,9,10), 
                     iid=TRUE)
pdf("TimeDependentAUC.age12.stage12.pdf", width = 4,height = 4.5)
#Step 6
plotAUCcurve(ROC_nomo, 
             conf.int=F,  
             conf.band=F,
             col = "red3")

plotAUCcurve(ROC_age, 
             conf.int=F, 
             conf.band=F,
             col = "green3",
             add = T)
plotAUCcurve(ROC_stage, 
             conf.int=F, #
             conf.band=F,
             col = "blue3",
             add = T)
plotAUCcurve(ROC_grade, 
             conf.int=F, 
             conf.band=F,
             col = "gray",
             add = T)

legend("topright",         
       c("Nomogram",
         #"riskScore",
         "Age", "Stage","Grade"), 
       col = c("red3",#"pink2",
               "green3", "blue3","gray"), 
       lty=1, lwd=3)
dev.off()       
#############################################################
#dca
#install.packages("rmda")
library(rms)
library(rmda)
library(foreign)
library(survival)
#
baseline.model <- decision_curve(fustat ~
                                   stage ,   
                                 data = rt, 
                                 thresholds = seq(0, 1.0, by = .01),
                                 study.design = 'cohort',  
                                 bootstraps = 10) 
#
full.model <- decision_curve(fustat ~Nomogram, 
                             data = rt,
                             thresholds = seq(0, 1.0, by = .01), 
                             bootstraps = 10)
#
pdf(file = "risk.DCA.age12.pdf", width = 4,height = 4)
plot_decision_curve( list(full.model, baseline.model),  
                     curve.names = c("Nomogram", "Stage"),  
                     col = c("red2", "blue2"), 
                     lty = c(1,1,2,2), 
                     lwd = c(2,2, 2, 1),
                     confidence.intervals = F,  #remove confidence intervals 
                     cost.benefit.axis = T, #remove cost benefit axis
                     legend.position = "topright") #remove the legend
dev.off()
###########################################

#
pdf(file="risk.calibration.age12.pdf", width=4.0, height=4.4)
#1
f <- cph(Surv(futime, fustat) ~ Nomogram, x=T, y=T, surv=T, data=rt, time.inc=1)
cal <- calibrate(f, cmethod="KM", method="boot", u=1, m=(nrow(rt)/3), B=1000)
plot(cal, xlim=c(0,1), ylim=c(0,1),
     xlab="Nomogram-predicted OS (%)", ylab="Observed OS (%)", lwd=1.5, col="forestgreen", sub=F)
#3
f <- cph(Surv(futime, fustat) ~ Nomogram, x=T, y=T, surv=T, data=rt, time.inc=3)
cal <- calibrate(f, cmethod="KM", method="boot", u=3, m=(nrow(rt)/3), B=1000)
plot(cal, xlim=c(0,1), ylim=c(0,1), 
     xlab="Nomogram-predicted OS (%)", ylab="Observed OS (%)", lwd=1.5, col="blue2", sub=F, 
     add=T
)
#5
f <- cph(Surv(futime, fustat) ~ Nomogram, x=T, y=T, surv=T, data=rt, time.inc=5)
cal <- calibrate(f, cmethod="KM", method="boot", u=5, m=(nrow(rt)/3), B=1000)
plot(cal, xlim=c(0,1), ylim=c(0,1), xlab="", ylab="",  lwd=1.5, col="gold3", sub=F, add=T)
#10
f <- cph(Surv(futime, fustat) ~ Nomogram, x=T, y=T, surv=T, data=rt, time.inc=10)
cal <- calibrate(f, cmethod="KM", method="boot", u=10, m=(nrow(rt)/3), B=1000)
plot(cal, xlim=c(0,1), ylim=c(0,1), xlab="", ylab="",  lwd=1.5, col="red3", sub=F, add=T)

legend('bottomright', c('1-year',
  '3-year', '5-year',"10-year"),
  col=c("forestgreen",
    "blue2","gold3","red3"), lwd=1.5, bty = 'n')
dev.off()



######################################################################
###
rm(list = ls())
cliFile="cli.all.txt"        
#
risk=read.table("nomoRisk.age12.stage12.txt", header=T, sep="\t", check.names=F, row.names=1)
#
cli=read.table(cliFile, header=T, sep="\t", check.names=F, row.names=1)
cli=as.data.frame(cli)
cli=cli[,c(1,3,4)]
#
samSample=intersect(row.names(risk), row.names(cli))
risk1=risk[samSample,,drop=F]
cli=cli[samSample,,drop=F]
rt=cbind(risk1[,c("futime", "fustat", "Nomogram")], cli)

#
#rt = rt[1:5]
#
bioCol=rainbow(ncol(rt)-1, s=0.9, v=0.9)
############
predictTime=5     
aucText=c()
pdf(file="cliROC_5.age12.pdf", width=4.2, height=4.5)
#
i=3
ROC_rt=timeROC(T=risk$futime,
               delta=risk$fustat,
               marker=risk$Nomogram, cause=1,
               weighting='aalen',
               times=c(predictTime),ROC=TRUE)
plot(ROC_rt, time=predictTime, col=bioCol[i-2], title=FALSE, lwd=2)
#aucText=c(paste0(predictTime,"year AUC"))
aucText=c(paste0("Nomogram", ", AUC=", sprintf("%.3f",ROC_rt$AUC[2])))
abline(0,1)
#
for(i in 4:ncol(rt)){
  ROC_rt=timeROC(T=rt$futime,
                 delta=rt$fustat,
                 marker=rt[,i], cause=1,
                 weighting='aalen',
                 times=c(predictTime),ROC=TRUE)
  plot(ROC_rt, time=predictTime, col=bioCol[i-2], title=FALSE, lwd=2, add=TRUE)
  aucText=c(aucText, paste0(colnames(rt)[i],", AUC=",sprintf("%.3f",ROC_rt$AUC[2])))
}
#
legend("bottomright", aucText,lwd=2,bty="n",col=bioCol[1:(ncol(rt)-1)])
dev.off()


################################################################################
################################################################################
#########################################################