
#if (!requireNamespace("BiocManager", quietly = TRUE))
#    install.packages("BiocManager")
#BiocManager::install("ComplexHeatmap")

rm(list = ls())
library(ComplexHeatmap)
riskFile="risk.all.txt"     
cliFile="cli.all.txt"      
risk=read.table(riskFile, header=T, sep="\t", check.names=F, row.names=1)
risk=risk[order(risk$riskScore),] 
risk = risk[,c(2, ncol(risk))]
colnames(risk) = c("survival", "risk")
risk[,"survival"]=ifelse(risk[,"survival"]==1, "Dead", "Alive")
cli=read.table(cliFile,sep="\t",header=T,check.names=F,row.names=1)

cli[,"age"]=ifelse(cli[,"age"]=="unknow", "unknow", ifelse(cli[,"age"]>60,">60","<=60"))
cli[,"gender"]=ifelse(cli[,"gender"]==1, "Male", "Female")
cli[,"stage"]=ifelse(cli[,"stage"]==1, "I-II", ifelse(cli[,"stage"]>4,"III-IV",
                                                      ifelse(cli[,"stage"]>3,"III-IV",
                                                             ifelse(cli[,"stage"]>2,"III-IV","I-II"))))
cli[,"grade"]=ifelse(cli[,"grade"]==1, "G1-G2", ifelse(cli[,"grade"]>4,"Unknown",
                                                       ifelse(cli[,"grade"]>3,"G3-G4",
                                                              ifelse(cli[,"grade"]>2,"G3-G4","G1-G2"))))
cli[,"M"]=ifelse(cli[,"M"]==1, "M0", ifelse(cli[,"M"]>2,"Unknown","M1"))
cli[,"N"]=ifelse(cli[,"N"]==1, "N0", ifelse(cli[,"N"]>2,"Unknown","N1"))
cli[,"T"]=ifelse(cli[,"T"]==1, "I-II", ifelse(cli[,"T"]>4,"Unknown",
                                              ifelse(cli[,"T"]>3,"III-IV",
                                                     ifelse(cli[,"T"]>2,"III-IV","I-II"))))

samSample=intersect(row.names(risk), row.names(cli))
risk=risk[samSample,,drop=F]

cli=cli[samSample,,drop=F]
rt=cbind(cli, risk)

#
sigVec=c()
for(clinical in colnames(rt[,1:(ncol(rt)-1)])){
	data=rt[c("risk", clinical)]
	colnames(data)=c("risk", "clinical")
	data=data[(data[,"clinical"]!="Unknown"),]
	tableStat=table(data)
	stat=chisq.test(tableStat)
	pvalue=stat$p.value
	Sig=ifelse(pvalue<0.001,"***",ifelse(pvalue<0.01,"**",ifelse(pvalue<0.05,"*","")))
	sigVec=c(sigVec, paste0(clinical, Sig))
	#print(tableStat)
	#print(paste(clinical, pvalue, Sig, sep="\t"))
}
sigVec=c(sigVec, "risk")
colnames(rt)=sigVec
rt$risk=factor(rt$risk, levels=c("low","high"))

#
#rt=rt[apply(rt,1,function(x)any(is.na(match('unknow',x)))),,drop=F]
bioCol=c("#0066FF","#FF9900","#FF0000","#ed1299", "#0dbc21", "#246b93", "#cc8e12", "#d561dd", "#c93f00", 
         "#ce2523", "#f7aa5d", "#9ed84e", "#39ba30", "#6ad157", "#373bbf", "#a1ce4c", "#ef3bb6", "#d66551",
         "#1a918f", "#7149af", "#ff66fc", "#2927c4", "#57e559" ,"#8e3af4" ,"#f9a270" ,"#22547f", "#db5e92",
         "#4aef7b", "#e86502",  "#99db27", "#e07233", "#8249aa","#cebb10", "#03827f", "#931635", "#ff523f",
         "#edd05e", "#6f25e8", "#0dbc21", "#167275", "#280f7a", "#6373ed", "#5b910f" ,"#7b34c1" ,"#0cf29a" ,"#d80fc1",
         "#dd27ce", "#07a301", "#ddd53e",  "#391c82", "#2baeb5","#925bea", "#09f9f5",  "#63ff4f")
colorList=list()
j=0
for(cli in colnames(rt[,1:(ncol(rt)-1)])){
	cliLength=length(levels(factor(rt[,cli])))
	cliCol=bioCol[(j+1):(j+cliLength)]
	j=j+cliLength
	names(cliCol)=levels(factor(rt[,cli]))
	cliCol["Unknown"]="grey75"
	colorList[[cli]]=cliCol
}
colorList[["risk"]]=c("low"="blue", "high"="red")

#
ha=HeatmapAnnotation(df=rt, col=colorList)
zero_row_mat=matrix(nrow=0, ncol=nrow(rt))
Hm=Heatmap(zero_row_mat, top_annotation=ha)

#
pdf(file="heatmap.pdf", width=7.5, height=3.2)
draw(Hm, merge_legend=TRUE, heatmap_legend_side="bottom", annotation_legend_side="bottom")
dev.off()

