
#if (!requireNamespace("BiocManager", quietly = TRUE))
#    install.packages("BiocManager")
#BiocManager::install("limma")

#install.packages("ggpubr")

rm(list = ls())
library(limma)
library(ggpubr)
riskFile="risk.all.txt"     
cliFile="cli.all.txt"       
risk=read.table(riskFile, header=T, sep="\t", check.names=F, row.names=1)
risk$riskScore[risk$riskScore>quantile(risk$riskScore,0.99)]=quantile(risk$riskScore,0.99)
risk = risk[,c(2, ncol(risk)-1,ncol(risk))]
colnames(risk) = c("survival", "riskScore", "risk")
risk = risk[,c(2,3,1)]
risk[,"survival"]=ifelse(risk[,"survival"]==1, "Dead", "Alive")
risk$riskScore = log2(risk$riskScore)
cli=read.table(cliFile, header=T, sep="\t", check.names=F, row.names=1)
cli[,"age"]=ifelse(cli[,"age"]=="unknow", "unknow", ifelse(cli[,"age"]>60,">60","<=60"))
cli[,"gender"]=ifelse(cli[,"gender"]==1, "Male", "Female")
cli[,"stage"]=ifelse(cli[,"stage"]==1, "I-II", ifelse(cli[,"stage"]>4,"III-IV",
                                                   ifelse(cli[,"stage"]>3,"III-IV",
                                                          ifelse(cli[,"stage"]>2,"III-IV","I-II"))))
cli[,"grade"]=ifelse(cli[,"grade"]==1, "G1-G2", ifelse(cli[,"grade"]>4,"Unknown",
                                                      ifelse(cli[,"grade"]>3,"G3-G4",
                                                             ifelse(cli[,"grade"]>2,"G3-G4","G1-G2"))))
cli[,"M"]=ifelse(cli[,"M"]==1, "M0", ifelse(cli[,"M"]>2,"Unknown","M1"))
cli[,"N"]=ifelse(cli[,"N"]==1, "N0", ifelse(cli[,"N"]>2,"Unknown","N1"))
cli[,"T"]=ifelse(cli[,"T"]==1, "I-II", ifelse(cli[,"T"]>4,"Unknown",
                                                      ifelse(cli[,"T"]>3,"III-IV",
                                                             ifelse(cli[,"T"]>2,"III-IV","I-II"))))
samSample=intersect(row.names(risk), row.names(cli))
risk=risk[samSample,,drop=F]
cli=cli[samSample,,drop=F]
rt=cbind(risk, cli)

for(clinical in colnames(rt[,2:ncol(rt)])){
	data=rt[c("riskScore", clinical)]
	colnames(data)=c("riskScore", "clinical")
	data=data[(data[,"clinical"]!="unknow"),]
	group=levels(factor(data$clinical))
	data$clinical=factor(data$clinical, levels=group)
	comp=combn(group,2)
	my_comparisons=list()
	for(i in 1:ncol(comp)){my_comparisons[[i]]<-comp[,i]}
	boxplot=ggboxplot(data, x="clinical", y="riskScore", fill="clinical",
		          xlab=clinical,
		          ylab="Risk score (log2)",
		          legend.title=clinical)+ 
	    stat_compare_means(comparisons = my_comparisons)
	pdf(file=paste0("clinicalCor_", clinical, ".pdf"), width=3.5, height=4)
	print(boxplot)
	dev.off()
}




