#install.packages("survival")
#install.packages("survminer")
rm(list = ls())
library(survival)
library(survminer)
riskFile="risk.all.txt"     
cliFile="cli.all.txt"      

risk=read.table(riskFile, header=T, sep="\t", check.names=F, row.names=1)    
cli=read.table(cliFile, header=T, sep="\t", check.names=F, row.names=1)      
#cli= cli [,c(1,3:7)]
cli[,"age"]=ifelse(cli[,"age"]=="unknow", "unknow", ifelse(cli[,"age"]>60,">60 years","<=60 years"))
cli[,"gender"]=ifelse(cli[,"gender"]==1, "Male", "Female")
cli[,"stage"]=ifelse(cli[,"stage"]==1, "Stage I-II", ifelse(cli[,"stage"]>4,"Stage III-IV",
                                                      ifelse(cli[,"stage"]>3,"Stage III-IV",
                                                             ifelse(cli[,"stage"]>2,"Stage III-IV","Stage I-II"))))
cli[,"grade"]=ifelse(cli[,"grade"]==1, "G1-2", ifelse(cli[,"grade"]>4,"Unknown",
                                                       ifelse(cli[,"grade"]>3,"G3-4",
                                                              ifelse(cli[,"grade"]>2,"G3-4","G1-2"))))
cli[,"M"]=ifelse(cli[,"M"]==1, "M0", ifelse(cli[,"M"]>2,"Unknown","M1"))
cli[,"N"]=ifelse(cli[,"N"]==1, "N0", ifelse(cli[,"N"]>2,"Unknown","N1"))
cli[,"T"]=ifelse(cli[,"T"]==1, "T1-2", ifelse(cli[,"T"]>4,"Unknown",
                                              ifelse(cli[,"T"]>3,"T3-4",
                                                     ifelse(cli[,"T"]>2,"T3-4","T1-2"))))
sameSample=intersect(row.names(cli), row.names(risk))
risk=risk[sameSample,]
cli=cli[sameSample,]
data=cbind(futime=risk[,1],fustat=risk[,2],cli,risk=risk[,"risk"])

for(i in colnames(data[,3:(ncol(data)-1)])){
  rt=data[,c("futime","fustat",i,"risk")]
  rt=rt[(rt[,i]!="Unknown"),]
  colnames(rt)=c("futime","fustat","clinical","risk")
  tab=table(rt[,"clinical"])
  tab=tab[tab!=0]
  
  for(j in names(tab)){
    rt1=rt[(rt[,"clinical"]==j),]
    tab1=table(rt1[,"risk"])
    tab1=tab1[tab1!=0]
    labels=names(tab1)
    if(length(labels)==2){
      titleName=j
      if((i=="age") | (i=="Age") | (i=="AGE")){
        titleName=paste0("age",j)
      }
      diff=survdiff(Surv(futime, fustat) ~risk,data = rt1)
      pValue=1-pchisq(diff$chisq,df=1)
      if(pValue<0.001){
        pValue="p<0.001"
      }else{
        pValue=paste0("p=",sprintf("%.03f",pValue))
      }
      fit <- survfit(Surv(futime, fustat) ~ risk, data = rt1)
      #
      surPlot=ggsurvplot(fit, 
                         data=rt1,
                         conf.int=T,
                         pval=pValue,
                         pval.size=8,
                         title=paste0("Patients with ",titleName),
                         legend.title="Risk",
                         legend.labs=labels,
                         font.legend=10,
                         xlab="Time(years)",
                         break.time.by = 2,
                         palette=c("hotpink", "springgreen"),
                         risk.table=TRUE,
                         risk.table.title="",
                         risk.table.col = "strata",
                         risk.table.height=.27)
      
      j=gsub(">=","ge",j);j=gsub("<=","le",j);j=gsub(">","gt",j);j=gsub("<","lt",j)
      pdf(file=paste0("sur.",i,"_",j,".pdf"),onefile = FALSE,
          width = 3.5,        
          height =4.7)       
      print(surPlot)
      dev.off()
    }
  }
}

