#if (!requireNamespace("BiocManager", quietly = TRUE))
#    install.packages("BiocManager")
#BiocManager::install("limma")
#install.packages("ggpubr")
library(limma)
library(ggpubr)
riskFile="risk.all.txt" 
subtypeFile="Subtype_Immune_Model_Based.txt"
subtype=read.table(subtypeFile, header=T, sep="\t", check.names=F, row.names=1)
rownames(subtype)=gsub("(.*?)\\-(.*?)\\-(.*?)\\-.*", "\\1\\-\\2\\-\\3", rownames(subtype))
colnames(subtype)[1]="subtype"
subtype[,"subtype"]=gsub(".+Immune |\\)", "", subtype[,"subtype"])
risk=read.table(riskFile, header=T, sep="\t", check.names=F, row.names=1)
risk$riskScore[risk$riskScore>quantile(risk$riskScore,0.99)]=quantile(risk$riskScore,0.99)
sameSample=intersect(row.names(subtype), row.names(risk))
subtype=subtype[sameSample,,drop=F]
risk=risk[sameSample,"riskScore",drop=F]
data=cbind(subtype, risk)
data$riskScore = log2(data$riskScore)
typeTab=table(data$subtype)
typeName=names(typeTab[typeTab>6])
data=data[which(data[,"subtype"] %in% typeName),]
group=levels(factor(data$subtype))
data$subtype=factor(data$subtype, levels=group)
comp=combn(group,2)
my_comparisons=list()
for(i in 1:ncol(comp)){my_comparisons[[i]]<-comp[,i]}
boxplot=ggboxplot(data, x="subtype", y="riskScore", fill="subtype",
		          xlab="",
		          ylab="Risk score (log2)",
		          legend.title="Immune subtype")+ 
	    stat_compare_means(comparisons = my_comparisons)
pdf(file="immuneSubtype.pdf", width=5, height=5.5)
print(boxplot)
dev.off()




